@@ -2,16 +2,19 @@ import requests
 
 from hypyxel.errors import UUIDNotFoundError, ApiKeyError
 
-key = ""
+def init():
+    global key
+    key = ""
 
 def _get_uuid(username):
     try:
-        return requests.request("GET", f"https://playerdb.co/api/player/minecraft/{username}")['data']['player']['meta']['raw_id']
+        return requests.request("GET", f"https://playerdb.co/api/player/minecraft/{username}").json()['data']['player']['raw_id']
     except:
         raise UUIDNotFoundError(f"A UUID could not be found for {username}")
 
 def set_api_key(user_key):
     """Set the API key"""
+    init()
     global key
     key = user_key
 
